==> django-localflavor-2.1.tar.gz: django-localflavor-2.1/docs/_build/html/localflavor/hk.html.py <==
XXXXXXXXX XXXX XXXXXX XXXXXXXXXXXX XXXXX XXX XXXXXXXXXXXXXXXXX
  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX


XXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
  XXXXXX
    XXXXX XXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXX XX
    
    XXXXXXXXXXX XXXX XXXX XXXXXXX XXXXXXXXXXXXXXXXXX XXX XXXXXXXXXXXXXXXXXXXXX
    
    XXXXX XXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXX XX
    XXXXX XXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXX XX
    
    XXXXXXX XXXXXXXXXXXXXXXXXXXXXXX
      XXX XXXXXXXXXXXXXXXXXXXXX X X
        XXXXXXXXX    XXXXXX
        XXXXXXXX     XXXXXX
        XXXXXXXXXXXXXXX XXXXXX
        XXXXXXXXXXXX XXXXXXXX
        XXXXXXXXXXX  XXXXX
        XXXXXXXXXXXXXXXXXX XXXXXX
      XX
    XXXXXXXXX
    XXXXXXX XXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
    XXXXXXX XXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
    XXXXXXX XXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
    XXXXX XXXXXXXXXXX XXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXX XX
    XXXXX XXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXX XX
    XXXXX XXXXXXXXXX XXXXXXXXXXXXXX XXXXX XXXXXXXXXXXXXX XX
    XXXXX XXXXXXXXXX XXXXXXXXXXXXX XXXXX XXXXXXXXXXXXXX XX 
  XXXXXXX
  XXXXX XXXXXXXXXXXXXXXX
    XXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXX XXXXXXXXXXXX
      XXXXXXXXXXXXXXXXXXX
      XXXX
        XXX XXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXX XXXXXX
          XX XXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXX
             XXXXXXXXXXXXXXXXXXXXXXXXXXXX
        XXX XXXXXXXXXXXXX X
          XX XXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXX XXXXXX XXXXXX
             XXXXXXXXXXXX XXXXXX
        XXX XXXXXXXXXXXXX X
          XX XXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXX
             XXXXXXXXXXXXXXXXXXXXXX XXXXXX
        XXX XXXXXXXXXXXXX X
          XX XXXXXXXXXXXXXX XXXXXXXXXXXXX XXXXX
             XXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXX
        XXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXX XXXXXXXXXXXXXXXXX XXXXXXXXXXX 
      XXXXX
    XXXXXX  

    XXXX XXXXXXXXXXXXXXXXX
      XXXX XXXXXXXXXXXXXXXXXXXXXXXX
        XXXX XXXXXXXXXXXXXXXXXXXX
          XXXX XXXXXXXXXXXX XXXXXXXXXXXX
            
  XXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXX
XXXXXXXX XXXX XXXXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXX XX XXXX XXXXXXXXXXXXXXXXXXXX
XXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXX XX XXXX XXXXXXXXXXXXXXXXXXXX
XXXXXXX XXXX XXXXXXXX XXXX XXXXXXXXXXXX
XXX XXXXXXXXXXXXXX
XXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXX XXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXX XXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXX XX XXXX XXXXXXXXXXXXXXXXXXXXXX
XXXXXXXX XXXX XXXXX XXXX XXXXXXXXX XXXX XXXX XXXXX XXXXXXXXXXXX
XXXXXX XXXXX XXXXXX XXX XX XXXXXX XXX XX XXX XXXXXXXXXXX
XXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXX XXXXXXXXXXXXXXXXX
XXXXXXXXXXX XXXXXXXXXXXX XX XXXXXXXXXXXXXXXXXXXXXXX
XXX XXXXXX XXXXXX XX XXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXX XXXXXXXXXXXXXXXXX
XXXXXXXXX XXX XXXXX XXXXXX XXXXX XXX XXXXX XXXX XXXX XXXX XX XXXXXXXXX
XXXXXXXX XX XXXXXX XXXXX XXXX XXXXXX XX XX XX XX XX XX XXXXXXX
XXXXX
XXXXX XXXXXXXXXXXXXXXX XXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXXXX

XXXXXX
XXXXXX


          XXXXXX
        XXXXXX
      XXXXXX
      XXXX XXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXX XXXXXXXXXXXX
        XXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXX
  XXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXX XX XXXXXXXXXXXXXXXXX
  XXXX
XXXXXX XXXXXXXXXXXXXXXX XXXXXXXXX XXXXXXXXXXXXX XXXX XXXXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXX XXXXXXXXXXXXXXXX XXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXX
XXXXX
XXXXX

  XXXXXXXXXXXX XXXXXXXXXX
  XX XXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXX
                        XXXXXXXXXXXXXXX XXXXXXXXXXXXXXX XXXXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
  XXXXXXXX XXXXXXXXXX
  XX XXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXX
                        XXXXXXXXXXX XXXXXXXXXXXXXXXX XXXXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
  XXXX XXXXXXXXXXX XXXXXXXXXXXXXXXXXX XXXXXX
    XXXXXXXX XXXXXXXXX
    XXX XXXXXXXXXXXXXXXXXXXXXXX
      XXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
            XXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXX
    XXXXX
   XXXXXX
XXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXX XXXXX XXXXXXXXXXXXXX
  XXXXXXXXX XXXXXXXXXXX
    XXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXX
      XXXXXXXXXXX XXXXXXXXXXX XXXXXXXX XXXXXXXX
      XXXXXXXXXXX XXXXXXXXXXXXX XXXXXXXXXX XXXXXXXX
      XXXXXX XXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXX XX
      XXXXXX XXXXXXXXXXXXX XXXXXXXXXXX XXXXXXXXXXXXXXX XX
    XXXXXXX
XXXXXX
XXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
        XXXXXX
      XXXXXX
      XXXX XXXXXXXXXXXXXXXXXXXXXX
    XXXXXX
    XXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXX XXXXXXXXXXXX
      XXXXXXXXXXXXXXXXXXX
      XXXX
        XXX XXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXX XXXXXX
          XX XXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXX
             XXXXXXXXXXXXXXX
        XXX XXXXXXXXXXXXX X
          XX XXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXX XXXXXX XXXXXX
             XXXXXXXXXXXX XXXXXX
        XXX XXXXXXXXXXXXX X
          XX XXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXX
             XXXXXXXXX XXXXXX
        XXX XXXXXXXXXXXXX X
          XX XXXXXXXXXXXXXX XXXXXXXXXXXXX XXXXX
             XXXXXXXXXXXXX XXXXXX
        XXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXX XXXXXXXXXXXXXXXXX XXXXXXXXXXX 
      XXXXX
    XXXXXX
    XXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXX
        XXXXXX XXXXXXXXX XXXXXX XXXXXXXX XXXXXXXXXX XXX XXXXXXXXXX XXXXXXXXXXXXX
      XXXXXXX XXXXX XX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXX
    XXXXXX
  XXXXXXX
XXXXXXX

==> django-localflavor-3.1.tar.gz: django-localflavor-3.1/docs/_build/html/localflavor/hk.html.py <==

XXXXXXXXX XXXX XXXXXX XXXXXXXXXXXX XXXXX XXX XXXXXXXXXXXXXXXXX
  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

XXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
  XXXXXX
    XXXXX XXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXX XX
    XXXXXXXXXXX XXXX XXXX XXXXXXX XXXXXXXXXXXXXXXXXX XXXXX XXXXXXXXXXXXXXXXXXXXX
    XXXXX XXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXX XX
    XXXXX XXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXX XX
    XXXXXXX XXXXXXXXXXXXXXXXXXXXXXX
      XXX XXXXXXXXXXXXXXXXXXXXX X X
        XXXXXXXXX    XXXXXX
        XXXXXXXX     XXXXXXXX
        XXXXXXXXXXXXXXX XXXXXX
        XXXXXXXXXXXX XXXXXXXX
        XXXXXXXXXXX  XXXXX
        XXXXXXXXXXXXXXXXXX XXXXXX
      XX
    XXXXXXXXX
    XXXXXXX XXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
    XXXXXXX XXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
    XXXXXXX XXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
    XXXXX XXXXXXXXXXX XXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXX XX
    XXXXX XXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXX XX
    XXXXX XXXXXXXXXX XXXXXXXXXXXXXX XXXXX XXXXXXXXXXXXXX XX
    XXXXX XXXXXXXXXX XXXXXXXXXXXXX XXXXX XXXXXXXXXXXXXX XX 
  XXXXXXX
  XXXXXX
    XXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXX XXXXXXXXXXXX
      XXXXXXXXXXXXXXXXXXX
      XXXX
        XXX XXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXX XXXXXX
          XX XXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXX
             XXXXXXXXXXXXXXXXXXXXXXXXXXXX
        XXX XXXXXXXXXXXXX X
          XX XXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXX XXXXXX XXXXXX
             XXXXXXXXXXXX XXXXXX
        XXX XXXXXXXXXXXXX X
          XX XXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXX
             XXXXXXXXXXXXXXXXXXXXXX XXXXXX
        XXX XXXXXXXXXXXXX X
          XX XXXXXXXXXXXXXX XXXXXXXXXXXXX XXXXX
             XXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXX
        XXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXX XXXXXXXXXXXXXXXXX XXXXXXXXXXX 
      XXXXX
    XXXXXX  

    XXXX XXXXXXXXXXXXXXXXX
      XXXX XXXXXXXXXXXXXXXXXXXXXXXX
        XXXX XXXXXXXXXXXXXXXXXXXX
          XXXX XXXXXXXXXXXX XXXXXXXXXXXX
            
  XXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXX
XXXXXXXX XXXX XXXXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXX XX XXXX XXXXXXXXXXXXXXXXXXXX
XXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXX XX XXXX XXXXXXXXXXXXXXXXXXXX
XXXXXXX XXXX XXXXXXXX XXXX XXXXXXXXXXXX
XXX XXXXXXXXXXXXXX
XXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXX XXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXX XXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXX XX XXXX XXXXXXXXXXXXXXXXXXXXXX
XXXXXXXX XXXX XXXXX XXXX XXXXXXXXX XXXX XXXX XXXXX XXXXXXXXXXXX
XXXXXX XXXXX XXXXXX XXX XX XXXXXX XXX XX XXX XXXXXXXXXXX
XXXXXXXXXXXX XXXXXXXXXXXXXXXX XXXXXXX XXXXXXXXXXX
XXXXX XXXXXX XX XXXXXXXXXXX
XXX XXXXXX XXXXXX XX XXXXXXXXXXXXXXXX
XXX XXXXXXXXXXXXXXXXX
XXXXXXXXX XXX XXXXX XXXXXX XXXXX XXX XXXXX XXXX XXXX XXXX XX XXXXXXXXX
XXXXXXXX XX XXXXXX XXXXX XXXX XXXXXX XX XX XX XX XX XX XXXXXXX
XXXXX
XXXXX XXXXXXXXXXXXXXXX XXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXX XXXXXXXXXXXXXXXXXXX
XXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXX XXXXXXX XXXX XXXXXXXXXX XXX XX XXXXXXXXXXXXXXXX XXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXX XXXXXXXXXXXX
XXXXXX
XXXXXXXXXX

XXXXXX
XXXXXX


          XXXXXX
        XXXXXX
      XXXXXX
      XXXX XXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXX XXXXXXXXXXXX
        XXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXX
  XXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXX XX XXXXXXXXXXXXXXXXX
  XXXX
XXXXXX XXXXXXXXXXXXXXXX XXXXXXXXX XXXXXXXXXXXXX XXXX XXXXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXX XXXXXXXXXXXXXXXX XXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXX
XXXXX
XXXXX

  XXXXXXXXXXXX XXXXXXXXXX
  XX XXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXX
                        XXXXXXXXXXXXXXX XXXXXXXXXXXXXXX XXXXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
  XXXXXXXX XXXXXXXXXX
  XX XXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXX
                        XXXXXXXXXXX XXXXXXXXXXXXXXXX XXXXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
  XXXX XXXXXXXXXXX XXXXXXXXXXXXXXXXXX XXXXXX
    XXXXXXXX XXXXXXXXX
    XXX XXXXXXXXXXXXXXXXXXXXXXX
      XXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
            XXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXX
    XXXXX
   XXXXXX
XXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXX XXXXX XXXXXXXXXXXXXX
  XXXXXXXXX XXXXXXXXXXX
    XXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXX
      XXXXXXXXXXX XXXXXXXXXXX XXXXXXXX XXXXXXXX
      XXXXXXXXXXX XXXXXXXXXXXXX XXXXXXXXXX XXXXXXXX
      XXXXXX XXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXX XX
      XXXXXX XXXXXXXXXXXXX XXXXXXXXXXX XXXXXXXXXXXXXXX XX
    XXXXXXX
XXXXXX
XXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
        XXXXXX
      XXXXXX
      XXXX XXXXXXXXXXXXXXXXXXXXXX
    XXXXXX
    XXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXX XXXXXXXXXXXX
      XXXXXXXXXXXXXXXXXXX
      XXXX
        XXX XXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXX XXXXXX
          XX XXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXX
             XXXXXXXXXXXXXXX
        XXX XXXXXXXXXXXXX X
          XX XXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXX XXXXXX XXXXXX
             XXXXXXXXXXXX XXXXXX
        XXX XXXXXXXXXXXXX X
          XX XXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXX
             XXXXXXXXX XXXXXX
        XXX XXXXXXXXXXXXX X
          XX XXXXXXXXXXXXXX XXXXXXXXXXXXX XXXXX
             XXXXXXXXXXXXX XXXXXX
        XXX XXXXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXX XXXXXXXXXXXXXXXXX XXXXXXXXXXX 
      XXXXX
    XXXXXX
    XXXX XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXX
        XXXXXX XXXXXXXXX XXXXXX XXXXXXXX XXXXXXXXXX XXX XXXXXXXXXX XXXXXXXXXXXXX
      XXXXXXX XXXXX XX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXX
    XXXXXX
  XXXXXXX
XXXXXXX
